@@ -13,11 +13,13 @@
 #include <qpoint.h>
 #include <qpainter.h>
 #include <qpixmap.h>
-#include <atom.h>
+#include "atom.h"
 #include <qvaluelist.h>
 
 class KSimpleConfig;
 
+#define MOLEK_SIZE 15
+
 class Molek : public QWidget
 {
     Q_OBJECT
@@ -39,7 +41,7 @@ protected:
 
 private:
    QPixmap data;
-   uint molek[15][15]; // the indexes within atoms
+   uint molek[MOLEK_SIZE][MOLEK_SIZE]; // the indexes within atoms
    QValueList<atom> atoms;
    QString mname;
    QSize _size;
