@@ -16,9 +16,9 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-  $Id: kbgfibschat.cpp 323700 2004-06-26 07:08:31Z binner $
+  $Id: kbgfibschat.cpp 465369 2005-09-29 14:33:08Z mueller $
 
 */
 
