@@ -15,9 +15,9 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-  $Id: kbg.h 313636 2004-05-22 23:26:49Z bmeyer $
+  $Id: kbg.h 465369 2005-09-29 14:33:08Z mueller $
 
 */
 
