@@ -15,9 +15,7 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
 #include <unistd.h>
 #ifdef HAVE_STROPTS_H
@@ -32,7 +30,8 @@
 #include <klocale.h>
 #include "kbattleshipserver.moc"
 
-KBattleshipServer::KBattleshipServer(int port) : KExtendedSocket(QString::null, port, inetSocket | passiveSocket)
+KBattleshipServer::KBattleshipServer(int port, const QString& name) 
+	: KExtendedSocket(QString::null, port, inetSocket | passiveSocket), m_name(name)
 {
 	m_port = port;
 	m_serverSocket = 0;
@@ -46,7 +45,10 @@ void KBattleshipServer::init()
 		emit sigServerFailure();
 		return;
 	}
-
+	m_service.setServiceName(m_name);
+	m_service.setType(BATTLESHIP_SERVICE);
+	m_service.setPort(m_port);
+	m_service.publishAsync();
 	m_connectNotifier = new QSocketNotifier(fd(), QSocketNotifier::Read, this);
 	QObject::connect(m_connectNotifier, SIGNAL(activated(int)), SLOT(slotNewConnection()));
 }
@@ -57,6 +59,7 @@ void KBattleshipServer::slotNewConnection()
 	accept(sock);
 	if(sock && m_serverSocket == 0)
 	{
+		m_service.stop();
 		m_serverSocket = sock;
 		m_readNotifier = new QSocketNotifier(sock->fd(), QSocketNotifier::Read, this);
 		QObject::connect(m_readNotifier, SIGNAL(activated(int)), this, SLOT(slotReadClient()));
