@@ -19,20 +19,17 @@
 #ifndef KSHIP_H
 #define KSHIP_H
 
-#include <qobject.h>
-
-class KShip : public QObject
+class KShip
 {
-	Q_OBJECT
 public:
 	KShip(int, int, int, int, int, bool = false);
-	~KShip();
 
 	int shipxstart();
 	int shipxstop();
 	int shipystart();
 	int shipystop();
 	int shiptype();
+	int shipTypeEnum(int x, int y);
 
 	bool placedLeft();
 	bool contains(int x, int y);
