@@ -15,29 +15,30 @@ class FEBoard : public Board
 
     uint nbPuyos() const { return _nbPuyos; }
     uint chained() const { return _chained; }
-
- signals:
-    void removedUpdated(uint chain, uint removed);
+    uint nbChainedPuyos(uint i) const { return _chainedPuyos[i]; }
+    uint lastChained() const { return _lastChained; }
 
  private:
 	// standard methods
 	bool afterGlue(bool doAll, bool first);
 	AfterRemoveResult afterRemove(bool doAll, bool first);
 	bool afterGift(bool first) { return !doFall(false, first, true); };
-    void removeBlock(const Grid2D::Coord &);
-    bool toBeRemoved(const Grid2D::Coord &) const;
-    bool toFall(const Grid2D::Coord &) const;
+    void removeBlock(const KGrid2D::Coord &);
+    bool toBeRemoved(const KGrid2D::Coord &) const;
+    bool toFall(const KGrid2D::Coord &) const;
 	void remove();
 	bool needRemoving();
     void computeInfos();
+    
+    void init();
 
 	// Multiplayers methods
 	uint gift();
 	bool putGift(uint);
 
-	Grid2D::Square<int> _field;
+	KGrid2D::Square<int> _field;
 	QMemArray<uint>     _groups, _chainedPuyos;
-	uint                _nbPuyos, _chained, _giftRest;
+	uint                _nbPuyos, _chained, _giftRest, _lastChained;
 };
 
 #endif
