@@ -1,22 +1,29 @@
 #include "piece.h"
 
 #include <qpainter.h>
-
+#include <klocale.h>
 #include "base/board.h"
 
 
-const QColor KLPieceInfo::COLORS[NB_BLOCK_TYPES] = {
-    QColor(200, 100, 100), // red
-	QColor(100, 200, 100), // green
-	QColor(100, 100, 200), // blue
-	QColor(200, 200, 100), // orange
-    QColor(200, 100, 200)  // violet
+const char *KLPieceInfo::DEFAULT_COLORS[NB_BLOCK_TYPES] = {
+    "#C86464", "#64C864", "#6464C8", "#C8C864", "#C864C8"
 };
 
+QColor KLPieceInfo::defaultColor(uint i) const
+{
+  if ( i>=nbColors() ) return QColor();
+  return QColor(DEFAULT_COLORS[i]);
+}
+
+QString KLPieceInfo::colorLabel(uint i) const
+{
+    return i18n("Color #%1:").arg(i+1);
+}
+
 void KLPieceInfo::draw(QPixmap *pixmap, uint blockType, uint bMode,
                        bool lighted) const
 {
-	QColor col = COLORS[blockType];
+	QColor col = color(blockType);
     if (lighted) col = col.light();
     pixmap->fill(col);
 
