@@ -1,6 +1,4 @@
 /***************************************************************************
-                          linesboard.h  -  description
-                             -------------------
     begin                : Fri May 19 2000
     copyright            : (C) 2000 by Roman Merzlyakov
     email                : roman@sbrf.barrt.ru
@@ -16,8 +14,9 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#ifndef __linesboard_h
-#define __linesboard_h
+
+#ifndef linesboard_h
+#define linesboard_h
 
 #include <qwidget.h>
 #include <qpixmap.h>
