@@ -1,5 +1,4 @@
-#include <sys/param.h>
-
+#include <kapplication.h>
 #include <kfiledialog.h>
 #include <klocale.h>
 #include <kmessagebox.h>
@@ -20,7 +19,7 @@
 
 static const char * themeMagicV1_0= "kmahjongg-theme-v1.0";
 
-Preview::Preview(QWidget* parent) : KDialogBase(parent), tiles(true)
+Preview::Preview(QWidget* parent) : KDialogBase(parent), m_tiles(true)
 {
 	KPushButton *loadButton;
 	QGroupBox *group;
@@ -30,16 +29,16 @@ Preview::Preview(QWidget* parent) : KDialogBase(parent), tiles(true)
 
 	group = new QHGroupBox(page);
 	
-	combo = new QComboBox(false, group);
-	connect(combo, SIGNAL(activated(int)), SLOT(selectionChanged(int)));
+	m_combo = new QComboBox(false, group);
+	connect(m_combo, SIGNAL(activated(int)), SLOT(selectionChanged(int)));
 
 	loadButton = new KPushButton(i18n("Load..."), group);
 	connect( loadButton, SIGNAL(clicked()), SLOT(load()) );
 	
-	drawFrame = new FrameImage(page);
-	drawFrame->setFixedSize(310, 236);
+	m_drawFrame = new FrameImage(page);
+	m_drawFrame->setFixedSize(310, 236);
 
-	changed = false;
+	m_changed = false;
 	
 	setMainWidget(page);
 	setFixedSize(sizeHint());
@@ -51,29 +50,30 @@ Preview::~Preview()
 
 void Preview::selectionChanged(int which)
 {
-	selectedFile = fileList[which];
+	m_selectedFile = m_fileList[which];
 	drawPreview();
-	drawFrame->repaint(0,0,-1,-1,false);
+	m_drawFrame->repaint(0,0,-1,-1,false);
 	markChanged();
 }
 
 bool Preview::isChanged()
 {
-	return changed;
+	return m_changed;
 }
 
 void Preview::markChanged()
 {
-	changed = true;
+	m_changed = true;
 }
 
 void Preview::markUnchanged()
 {
-	changed = false;
+	m_changed = false;
 }
 
-void Preview::initialise(const PreviewType type, const char *extension)
+void Preview::initialise(const PreviewType type)
 {
+	QString extension;
 	QString tile = Prefs::tileSet();
 	QString back = Prefs::background();
 	QString layout = Prefs::layout();
@@ -84,90 +84,64 @@ void Preview::initialise(const PreviewType type, const char *extension)
 	{
 		case background:
 			setCaption(i18n("Change Background Image"));
-			selectedFile = back;
-			fileSelector = i18n("*.bgnd|Background Image (*.bgnd)\n");
-			fileSelector += KImageIO::pattern()+"\n";
+			m_selectedFile = back;
+			m_fileSelector = i18n("*.bgnd|Background Image (*.bgnd)\n");
+			m_fileSelector += KImageIO::pattern()+"\n";
+			extension = "*.bgnd";
 		break;
 		
 		case tileset:
 			setCaption(i18n("Change Tile Set"));
-			fileSelector = i18n("*.tileset|Tile Set File (*.tileset)\n");
-			selectedFile = tile;
+			m_fileSelector = i18n("*.tileset|Tile Set File (*.tileset)\n");
+			m_selectedFile = tile;
+			extension = "*.tileset";
 		break;
 		
 		case board:
-			fileSelector = i18n("*.layout|Board Layout File (*.layout)\n");
+			m_fileSelector = i18n("*.layout|Board Layout File (*.layout)\n");
 			setCaption(i18n("Change Board Layout"));
-			selectedFile = layout;
+			m_selectedFile = layout;
+			extension = "*.layout";
 		break;
 		
 		case theme:
-			fileSelector = i18n("*.theme|KMahjongg Theme File (*.theme)\n");
+			m_fileSelector = i18n("*.theme|KMahjongg Theme File (*.theme)\n");
 			setCaption(i18n("Choose Theme"));
-			selectedFile="";
+			m_selectedFile="";
+			extension = "*.theme";
 			
-			themeLayout="";
-			themeBack="";
-			themeTileset="";
+			m_themeLayout="";
+			m_themeBack="";
+			m_themeTileset="";
 		
 		default:
 		break;
 	}
 	
-	fileSelector += i18n("*|All Files");
+	m_fileSelector += i18n("*|All Files");
 	enableButtonApply(type != board);
 
-	previewType = type;
+	m_previewType = type;
 	// we start with no change indicated
 	markUnchanged();
 
-	QString kmDir;
-	QDir files;
-	QFileInfo *current=new QFileInfo(selectedFile);
-
-	// we pick up system files from the kde dir
-	kmDir = locate("appdata", "pics/default.tileset");
-
-	QFileInfo f(kmDir);
-	kmDir = f.dirPath();
-
-	files.cd(kmDir);
-	files.setNameFilter(extension);
-	files.setFilter(QDir::Files | QDir::Readable);
+	m_fileList = kapp->dirs()->findAllResources("appdata",  "pics/*"+extension, false, true);
 
 	// get rid of files from the last invocation
-	fileList.clear();
-	combo->clear();
+	m_combo->clear();
 
-	// deep copy the file list as we need to keen to keep it
-	QFileInfoList *list = (QFileInfoList *) files.entryInfoList();
-	// put the curent entry in the returned list to test for
-	// duplicates on insertion
-
-	if (!current->fileName().isEmpty())
-		list->insert(0, current);
-
-	QFileInfo *info=list->first();
-	for (unsigned int p=0; p<list->count(); p++)
+	QStringList names;
+	QStringList::const_iterator it, itEnd;
+	it = m_fileList.begin();
+	itEnd = m_fileList.end();
+	for ( ; it != itEnd; ++it)
 	{
-		bool duplicate = false;
-
-		for (unsigned int c=0; c<fileList.count(); c++)
-		{
-			if (info->filePath() == fileList[c]) {
-				duplicate = true;
-			}
-		}
-
-		if (!duplicate)
-		{
-			fileList.append(info->filePath());
-			combo->insertItem(info->baseName());
-		}
-		info=list->next();
+		QFileInfo fi(*it);
+		names << fi.baseName();
 	}
-
-	combo->setEnabled(fileList.count());
+	
+	m_combo->insertStringList(names);
+	m_combo->setEnabled(m_fileList.count());
 	drawPreview();
 }
 
@@ -184,11 +158,11 @@ void Preview::slotOk() {
 }
 
 void Preview::load() {
-    KURL url = KFileDialog::getOpenURL(QString::null, fileSelector, this, i18n("Open Board Layout" ));
+    KURL url = KFileDialog::getOpenURL(QString::null, m_fileSelector, this, i18n("Open Board Layout" ));
     if ( !url.isEmpty() ) {
-        selectedFile = url.path();
+        m_selectedFile = url.path();
         drawPreview();
-        drawFrame->repaint(0,0,-1,-1,false);
+        m_drawFrame->repaint(0,0,-1,-1,false);
         markChanged();
     }
 }
@@ -204,65 +178,73 @@ void Preview::drawPreview()
 	QString back = Prefs::background();
 	QString layout = Prefs::layout();
 	
-	switch (previewType)
+	switch (m_previewType)
 	{
 		case background:
-			back = selectedFile;
+			back = m_selectedFile;
 		break;
 		
 		case tileset:
-			tile = selectedFile;
+			tile = m_selectedFile;
 		break;
 		
 		case board:
-			layout = selectedFile;
+			layout = m_selectedFile;
 		break;
 		
 		case theme:
 			// a theme is quite a bit of work. We load the
 			// specified bits in (layout, background and tileset
-			if (!selectedFile.isEmpty())
+			if (!m_selectedFile.isEmpty())
 			{
-				char backRaw[MAXPATHLEN];
-				char layoutRaw[MAXPATHLEN];
-				char tilesetRaw[MAXPATHLEN];
-				char magic[MAXPATHLEN];
+				QString backRaw, layoutRaw, tilesetRaw, magic;
 				
-				QFile in(selectedFile);
+				QFile in(m_selectedFile);
 				if (in.open(IO_ReadOnly))
 				{
-					in.readLine(magic, MAXPATHLEN);
-					if (magic[strlen(magic)-1]=='\n') magic[strlen(magic)-1]='\0';
-					if (strncmp(themeMagicV1_0, magic, strlen(magic)) != 0)
+					QTextStream stream(&in);
+					magic = stream.readLine();
+					if (magic != themeMagicV1_0)
 					{
 						in.close();
 						KMessageBox::sorry(this, i18n("That is not a valid theme file."));
 						break;
 					}
-					in.readLine(tilesetRaw, MAXPATHLEN);
-					in.readLine(backRaw, MAXPATHLEN);
-					in.readLine(layoutRaw, MAXPATHLEN);
-					
-					tile = QString("pics") + tilesetRaw;
-					back = QString("pics") + backRaw;
-					layout = QString("pics") + layoutRaw;
-					
-					layout.replace(QRegExp(":"), "/");
-					layout.replace(QRegExp("\n"), QString::null);
-					tile.replace(QRegExp(":"), "/");
-					tile.replace(QRegExp("\n"), QString::null);
-					back.replace(QRegExp(":"), "/");
-					back.replace(QRegExp("\n"), QString::null);
-					
-					tile = locate("appdata", tile);
-					back = locate("appdata", back);
-					layout = locate("appdata", layout);
-					
+					tilesetRaw = stream.readLine();
+					backRaw = stream.readLine();
+					layoutRaw = stream.readLine();
 					in.close();
 					
-					themeBack=back;
-					themeLayout=layout;
-					themeTileset=tile;
+					tile = tilesetRaw;
+					tile.replace(":", "/kmahjongg/pics/");
+					if (!QFile::exists(tile))
+					{
+						tile = tilesetRaw;
+						tile = "pics/" + tile.right(tile.length() - tile.find(":") - 1 );
+						tile = locate("appdata", tile);
+					}
+					
+					back = backRaw;
+					back.replace(":", "/kmahjongg/pics/");
+					if (!QFile::exists(back))
+					{
+						back = backRaw;
+						back = "pics/" + back.right(back.length() - back.find(":") - 1);
+						back = locate("appdata", back);
+					}
+					
+					layout = layoutRaw;
+					layout.replace(":", "/kmahjongg/pics/");
+					if (!QFile::exists(layout))
+					{
+						layout = layoutRaw;
+						layout = "pics/" + layout.right(layout.length() - layout.find(":") - 1);
+						layout = locate("appdata", layout);
+					}
+					
+					m_themeBack=back;
+					m_themeLayout=layout;
+					m_themeTileset=tile;
 				}
 			}
 		break;
@@ -273,7 +255,7 @@ void Preview::drawPreview()
 }
 
 void Preview::paintEvent( QPaintEvent*  ){
-  drawFrame->repaint(false);
+  m_drawFrame->repaint(false);
 }
 
 // the user selected ok, or apply. This method passes the changes
@@ -281,32 +263,32 @@ void Preview::paintEvent( QPaintEvent*  ){
 // (unnecessary on layout changes since it only effects the next game)
 void Preview::applyChange()
 {
-	switch (previewType)
+	switch (m_previewType)
 	{
 		case background:
-			loadBackground(selectedFile, false);
+			loadBackground(m_selectedFile, false);
 		break;
 		
 		case tileset:
-			loadTileset(selectedFile);
+			loadTileset(m_selectedFile);
 		break;
 		
 		case board:
-			loadBoard(selectedFile);
+			loadBoard(m_selectedFile);
 		break;
 		
 		case theme:
-			if (!themeLayout.isEmpty() && !themeBack.isEmpty() && !themeTileset.isEmpty())
+			if (!m_themeLayout.isEmpty() && !m_themeBack.isEmpty() && !m_themeTileset.isEmpty())
 			{
-				loadBackground(themeBack, false);
-				loadTileset(themeTileset);
-				loadBoard(themeLayout);
+				loadBackground(m_themeBack, false);
+				loadTileset(m_themeTileset);
+				loadBoard(m_themeLayout);
 			}
 		break;
     }
 
 	// don't redraw for a layout change
-	if (previewType == board  || previewType == theme) layoutChange();
+	if (m_previewType == board  || m_previewType == theme) layoutChange();
 	else boardRedraw(true);
 
 	// either way we mark the current value as unchanged
@@ -319,9 +301,9 @@ void Preview::renderBackground(const QString &bg) {
    QImage tmp;
    QPixmap *p;
    QPixmap *b;
-   p = drawFrame->getPreviewPixmap();
-   back.load(bg, p->width(), p->height());
-   b = back.getBackground();
+   p = m_drawFrame->getPreviewPixmap();
+   m_back.load(bg, p->width(), p->height());
+   b = m_back.getBackground();
    bitBlt( p, 0,0,
             b,0,0, b->width(), b->height(), CopyROP );
 }
@@ -329,12 +311,12 @@ void Preview::renderBackground(const QString &bg) {
 // This method draws a mini-tiled board with no tiles missing.
 
 void Preview::renderTiles(const QString &file, const QString &layout) {
-    tiles.loadTileset(file, true);
-    boardLayout.loadBoardLayout(layout);
+    m_tiles.loadTileset(file, true);
+    m_boardLayout.loadBoardLayout(layout);
 
-    QPixmap *dest = drawFrame->getPreviewPixmap();
-    int xOffset = tiles.width()/2;
-    int yOffset = tiles.height()/2;
+    QPixmap *dest = m_drawFrame->getPreviewPixmap();
+    int xOffset = m_tiles.width()/2;
+    int yOffset = m_tiles.height()/2;
     short tile = 0;
 
     // we iterate over the depth stacking order. Each successive level is
@@ -345,12 +327,12 @@ void Preview::renderTiles(const QString &file, const QString &layout) {
         for (int y = 0; y < BoardLayout::height; y++) {
             // drawing right to left to prevent border overwrite
             for (int x=BoardLayout::width-1; x>=0; x--) {
-                int sx = x*(tiles.qWidth()  )+xOffset;
-                int sy = y*(tiles.qHeight()  )+yOffset;
-                if (boardLayout.getBoardData(z, y, x) != '1') {
+                int sx = x*(m_tiles.qWidth()  )+xOffset;
+                int sy = y*(m_tiles.qHeight()  )+yOffset;
+                if (m_boardLayout.getBoardData(z, y, x) != '1') {
                     continue;
                 }
-                QPixmap *t = tiles.unselectedPixmaps(tile);
+                QPixmap *t = m_tiles.unselectedPixmaps(tile);
 
                 // Only one compilcation. Since we render top to bottom , left
                 // to right situations arise where...:
@@ -359,7 +341,7 @@ void Preview::renderTiles(const QString &file, const QString &layout) {
                 // we simply split the tile draw so the top half is drawn
                 // minus border
 
-                if ((x>1) && (y>0) && boardLayout.getBoardData(z,y-1,x-2)=='1'){
+                if ((x>1) && (y>0) && m_boardLayout.getBoardData(z,y-1,x-2)=='1'){
                     bitBlt( dest, sx+2, sy,
                         t, 2,0, t->width(), t->height()/2, CopyROP );
                     bitBlt( dest, sx, sy+t->height()/2,
@@ -375,8 +357,8 @@ void Preview::renderTiles(const QString &file, const QString &layout) {
                 tile = tile % 43;
             }
         }
-        xOffset +=tiles.shadowSize();
-        yOffset -=tiles.shadowSize();
+        xOffset +=m_tiles.shadowSize();
+        yOffset -=m_tiles.shadowSize();
     }
 }
 
