@@ -13,7 +13,7 @@
 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include "dialogs.h"
@@ -219,11 +219,11 @@ GameConfig::GameConfig()
     cb = new QCheckBox(i18n("Enable keyboard"), this, "kcfg_KeyboardGame");
     top->addWidget(cb);
 
-    cb = new QCheckBox(i18n("Pause if windows lose focus"), this, "kcfg_PauseFocus");
+    cb = new QCheckBox(i18n("Pause if window loses focus"), this, "kcfg_PauseFocus");
     top->addWidget(cb);
 
     cb = new QCheckBox(i18n("\"Magic\" reveal"), this, "kcfg_MagicReveal");
-    QWhatsThis::add(cb, i18n("Set flags and reveal cases where they are trivial."));
+    QWhatsThis::add(cb, i18n("Set flags and reveal squares where they are trivial."));
     connect(cb, SIGNAL(toggled(bool)), SLOT(magicModified(bool)));
     top->addWidget(cb);
 
@@ -273,13 +273,6 @@ AppearanceConfig::AppearanceConfig()
 {
     QVBoxLayout *top = new QVBoxLayout(this, KDialog::spacingHint());
 
-    KIntNumInput *in = new KIntNumInput(this, "kcfg_CaseSize");
-    in->setLabel(i18n("Case size:"));
-    in->setRange(4, 100);
-    top->addWidget(in);
-
-    top->addSpacing(2 * KDialog::spacingHint());
-
     QHBoxLayout *hbox = new QHBoxLayout(top);
     QGrid *grid = new QGrid(2, this);
     grid->setSpacing(KDialog::spacingHint());
