@@ -13,7 +13,7 @@
 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include "adviseFull.h"
@@ -449,8 +449,10 @@ float AdviseFull::variantNumberFraction(
 			dvr = size - dvr;
 			dvd = size - dvd;
 		}
-		while(dvr < dvd)
-			quotient *= ((float)(size-dvr))/++dvr;
+		while(dvr < dvd) {
+                        float num = size-dvr++;
+			quotient *= num/dvr;
+                }
 	}
 
 	// Sorry, expensive call, but I'm lazy :((
