@@ -123,9 +123,9 @@ Klondike::Klondike( bool easy, KMainWindow* parent, const char* _name )
 //  a target pile and that it is no longer needed on any of the play piles
 //  (this is why this function is recursive). This more ambitious rule lets
 //  us extend the base case with the second lowest value (2).
-bool Klondike::noLongerNeeded(Card::Values v, Card::Suits s) {
+bool Klondike::noLongerNeeded(Card::Rank r, Card::Suit s) {
 
-    if (v <= Card::Two) return true; //  Base case.
+    if (r <= Card::Two) return true; //  Base case.
 
     //  Find the 2 suits of opposite color. "- 1" is used here because the
     //  siuts are ranged 1 .. 4 but target_tops is indexed 0 .. 3. (Of course
@@ -135,22 +135,21 @@ bool Klondike::noLongerNeeded(Card::Values v, Card::Suits s) {
     if (s == Card::Clubs || s == Card::Spades)
         a = Card::Diamonds - 1, b = Card::Hearts - 1;
 
-    const Card::Values depending_value
-        = static_cast<Card::Values>(v - 1);
+    const Card::Rank depending_rank = static_cast<Card::Rank>(r - 1);
     return
-      (((target_tops[a] >= depending_value)
+      (((target_tops[a] >= depending_rank)
         ||
-        ((target_tops[a] >= depending_value - 1)
+        ((target_tops[a] >= depending_rank - 1)
          &&
          (noLongerNeeded
-              (depending_value, static_cast<Card::Suits>(a + 1)))))
+              (depending_rank, static_cast<Card::Suit>(a + 1)))))
        &&
-       ((target_tops[b] >= depending_value)
+       ((target_tops[b] >= depending_rank)
         ||
-        ((target_tops[b] >= depending_value - 1)
+        ((target_tops[b] >= depending_rank - 1)
          &&
          (noLongerNeeded
-              (depending_value, static_cast<Card::Suits>(b + 1))))));
+              (depending_rank, static_cast<Card::Suit>(b + 1))))));
 }
 
 bool Klondike::tryToDrop(Card *t)
@@ -163,8 +162,7 @@ bool Klondike::tryToDrop(Card *t)
     Pile *tgt = findTarget(t);
     if (tgt) {
         newHint
-            (new MoveHint
-                 (t, tgt, noLongerNeeded(t->value(), t->suit())));
+            (new MoveHint(t, tgt, noLongerNeeded(t->rank(), t->suit())));
         return true;
     }
     return false;
@@ -179,7 +177,7 @@ void Klondike::getHints() {
     {
         Card *c = target[i]->top();
         if (!c) continue;
-        target_tops[c->suit() - 1] = c->value();
+        target_tops[c->suit() - 1] = c->rank();
     }
 
 
@@ -205,7 +203,7 @@ void Klondike::getHints() {
                     continue;
 
                 if (play[j]->legalAdd(empty)) {
-                    if (((*it)->value() != Card::King) || it != list.begin()) {
+                    if (((*it)->rank() != Card::King) || it != list.begin()) {
                         newHint(new MoveHint(*it, play[j]));
                         break;
                     }
@@ -349,10 +347,10 @@ bool Klondike::startAutoDrop()
 
 bool Klondike::isGameLost() const
 {
-    kdDebug( 1111 ) << "Is the game lost?" << endl;
+    kdDebug( 11111 ) << "Is the game lost?" << endl;
 
     if (!deck->isEmpty()) {
-        kdDebug( 1111 ) << "We should only check this when the deck is exhausted." << endl;
+        kdDebug( 11111 ) << "We should only check this when the deck is exhausted." << endl;
         return false;
     }
 
@@ -363,8 +361,8 @@ bool Klondike::isGameLost() const
                 continue;
             }
             if ( pile->top()->suit() == target[ i ]->top()->suit() &&
-                 pile->top()->value() - 1 == target[ i ]->top()->value() ) {
-                kdDebug( 1111 ) << "No, the source pile's top card could be added to target pile " << i << endl;
+                 pile->top()->rank() - 1 == target[ i ]->top()->rank() ) {
+                kdDebug( 11111 ) << "No, the source pile's top card could be added to target pile " << i << endl;
                 return false;
             }
         }
@@ -380,11 +378,11 @@ bool Klondike::isGameLost() const
          * accessible, but only every third one.
          */
         for ( unsigned int i = 2; i < pile->cards().count(); i += 3 ) {
-	    kdDebug( 1111 ) << "Found card "<< pile->cards()[i]->name()<< endl;
+	    kdDebug( 11111 ) << "Found card "<< pile->cards()[i]->name()<< endl;
             srcPileCards += pile->cards()[ i ];
         }
         if ( !pile->cards().isEmpty() && pile->cards().count() % 3 != 0 ) {
-	    kdDebug( 1111 ) << "Found last card "<< pile->cards()[pile->cards().count() - 1]->name()<< endl;
+	    kdDebug( 11111 ) << "Found last card "<< pile->cards()[pile->cards().count() - 1]->name()<< endl;
             srcPileCards += pile->cards()[ pile->cards().count() - 1 ];
         }
     }
@@ -398,8 +396,8 @@ bool Klondike::isGameLost() const
             CardList::ConstIterator it  = srcPileCards.begin();
             CardList::ConstIterator end = srcPileCards.end();
             for ( ; it != end; ++it ) {
-                if ( ( *it )->value() == Card::King ) {
-                    kdDebug( 1111 ) << "No, the pile contains a king which we could move onto store " << i << endl;
+                if ( ( *it )->rank() == Card::King ) {
+                    kdDebug( 11111 ) << "No, the pile contains a king which we could move onto store " << i << endl;
                     return false;
                 }
             }
@@ -414,8 +412,8 @@ bool Klondike::isGameLost() const
                 CardList::ConstIterator it = ++cards.begin();
                 CardList::ConstIterator end = cards.end();
                 for ( ; it != end; ++it ) {
-                    if ( ( *it )->realFace() && ( *it )->value() == Card::King ) {
-                        kdDebug( 1111 ) << "No, store " << j << " contains a visible king which we could move onto store " << i << endl;
+                    if ( ( *it )->realFace() && ( *it )->rank() == Card::King ) {
+                        kdDebug( 11111 ) << "No, store " << j << " contains a visible king which we could move onto store " << i << endl;
                         return false;
                     }
                 }
@@ -424,8 +422,8 @@ bool Klondike::isGameLost() const
             Card *topCard = play[ i ]->top();
 
             // ...check whether the top card is an Ace (we can start a target)
-            if ( topCard->value() == Card::Ace ) {
-                kdDebug( 1111 ) << "No, store " << i << " has an Ace, we could start a target pile." << endl;
+            if ( topCard->rank() == Card::Ace ) {
+                kdDebug( 11111 ) << "No, store " << i << " has an Ace, we could start a target pile." << endl;
                 return false;
             }
 
@@ -435,8 +433,8 @@ bool Klondike::isGameLost() const
                     continue;
                 }
                 if ( target[ targetIdx ]->top()->suit() == topCard->suit() &&
-                     target[ targetIdx ]->top()->value() == topCard->value() - 1 ) {
-                    kdDebug( 1111 ) << "No, store " << i << "'s top card could be added to target pile " << targetIdx << endl;
+                     target[ targetIdx ]->top()->rank() == topCard->rank() - 1 ) {
+                    kdDebug( 11111 ) << "No, store " << i << "'s top card could be added to target pile " << targetIdx << endl;
                     return false;
                 }
             }
@@ -447,8 +445,8 @@ bool Klondike::isGameLost() const
             CardList::ConstIterator end = srcPileCards.end();
             for ( ; it != end; ++it ) {
                 if ( ( *it )->isRed() != topCard->isRed() &&
-                     ( *it )->value() == topCard->value() - 1 ) {
-                    kdDebug( 1111 ) << "No, the pile contains a card which we could add to store " << i << endl;
+                     ( *it )->rank() == topCard->rank() - 1 ) {
+                    kdDebug( 11111 ) << "No, the pile contains a card which we could add to store " << i << endl;
                     return false;
                 }
             }
@@ -466,15 +464,15 @@ bool Klondike::isGameLost() const
                 for ( ; it != end; ++it ) {
                     if ( ( *it )->realFace() &&
                          ( *it )->isRed() != topCard->isRed() &&
-                         ( *it )->value() == topCard->value() - 1 ) {
-                        kdDebug( 1111 ) << "No, store " << j << " contains a card which we could add to store " << i << endl;
+                         ( *it )->rank() == topCard->rank() - 1 ) {
+                        kdDebug( 11111 ) << "No, store " << j << " contains a card which we could add to store " << i << endl;
                         return false;
                     }
                 }
             }
         }
     }
-    kdDebug( 1111 ) << "Yep, all hope is lost." << endl;
+    kdDebug( 11111 ) << "Yep, all hope is lost." << endl;
     return true;
 }
 
