@@ -26,10 +26,7 @@ this software.
 #include <kaudioplayer.h>
 #include <kapplication.h>
 #include <kstandarddirs.h>
-#include <qaccel.h>
 #include <qbitmap.h>
-#include <qframe.h>
-#include <qimage.h>
 #include <qpainter.h>
 #include <qpixmap.h>
 #include <qtimer.h>
@@ -54,13 +51,6 @@ GameWidget::GameWidget(QWidget *parent, const char *name)
 
 	random.setSeed(0);
 
-	QAccel *accel = new QAccel(this);
-	accel->connectItem(accel->insertItem(Key_Up), this, SLOT(keyUp()));
-	accel->connectItem(accel->insertItem(Key_Down), this, SLOT(keyDown()));
-	accel->connectItem(accel->insertItem(Key_Left), this, SLOT(keyLeft()));
-	accel->connectItem(accel->insertItem(Key_Right), this, SLOT(keyRight()));
-	accel->connectItem(accel->insertItem(Key_Space), this, SLOT(keySpace()));
-
 	loadSprites();
 	setPieces(Pieces_Smiles);
 
