@@ -23,8 +23,8 @@ this software.
 
 #include "config.h"
 
-#include <kapp.h>
-#include <kstddirs.h>
+#include <kapplication.h>
+#include <kstandarddirs.h>
 #include <qframe.h>
 #include <qpainter.h>
 #include <qpixmap.h>
