@@ -1,260 +1,281 @@
-#include <qstring.h>
+/**
+ * Copyright Michel Filippi <mfilippi@sade.rhein-main.de>
+ *           Robert Williams
+ *           Andrew Chant <andrew.chant@utoronto.ca>
+ *           André Luiz dos Santos <andre@netvision.com.br>
+ *           Benjamin Meyer <ben+ksnake@meyerhome.net>
+ *
+ * This file is part of the ksnake package
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public License
+ * along with this library; see the file COPYING.LIB.  If not, write to
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
+
 #include <qwidget.h>
 
 #include "snake.h"
-#include "board.h"
-#include "pixServer.h"
 
 int opposite[4] = { S, N , W, E };
 
 int emptySq[4][4]={
-    { N, E, W, N },
-    { S, W, E, S },
-    { E, N, S, E },
-    { W, S, N, W }
+	{ N, E, W, N },
+	{ S, W, E, S },
+	{ E, N, S, E },
+	{ W, S, N, W }
 };
 
 Snake::Snake(Board *b, PixServer *p, Gate g, PixMap x)
 {
-    list.setAutoDelete( TRUE );
-    pixServer = p;
-    board = b;
-    gate  = g;
-    pixmap = x;
-    random.setSeed(0);
+	list.setAutoDelete( true );
+	pixServer = p;
+	board = b;
+	gate  = g;
+	pixmap = x;
+	random.setSeed(0);
 }
 
 void Snake::updateSamy()
 {
-    int x = tail();
-    while ( x > 0)
-	*list.at(x) = *list.at(--x);
+	int x = tail();
+	while ( x > 0)
+		*list.at(x) = *list.at(--x);
 }
 
 void Snake::zero()
 {
-    for ( Samy *sam = list.first(); sam != 0; sam = list.next() ) {
-	board->set(sam->index, empty);
-	pixServer->erase(sam->index);
-    }
+	for ( Samy *sam = list.first(); sam != 0; sam = list.next() ) {
+		board->set(sam->index, empty);
+		pixServer->erase(sam->index);
+	}
 }
 
 void Snake::appendSamy()
 {
-    Samy *sam = new Samy;
-    list.append(sam);
+	Samy *sam = new Samy;
+	list.append(sam);
 
-    int x = tail();
-    while ( x > 0)
-	*list.at(x) = *list.at(--x);
-
-    grow--;
+	int x = tail();
+	while ( x > 0)
+		*list.at(x) = *list.at(--x);
+	grow--;
 }
 
 void Snake::reset(int index, int border)
 {
+	Samy *sam = list.first();
 
-    Samy *sam = list.first();
-
-    switch (border) {
-    case N:
+	switch (border) {
+	case N:
 	sam->pixmap = (tail() == 0 ? HtailUp : HeadUp);
 	break;
-    case S:
+	case S:
 	sam->pixmap = (tail() == 0 ? HtailDown : HeadDown);
 	break;
-    case E:
+	case E:
 	sam->pixmap = (tail() == 0 ? HtailRight : HeadRight);
 	break;
-    case W:
+	case W:
 	sam->pixmap = (tail() == 0 ? HtailLeft : HeadLeft);
 	break;
-    }
+	}
 
-    sam->index = index;
-    sam->direction  = border;
+	sam->index = index;
+	sam->direction  = border;
 
-    if (tail() > 1) {
+	if (tail() > 1) {
 
 	sam = list.next();
 
 	if (sam->direction == border) {
-	    if (border == N || border == S)
+		if (border == N || border == S)
 		sam->pixmap = BodyVt;
-	    else
+		else
 		sam->pixmap = BodyHz;
 	}
 	else {
-	    if (border == W && sam->direction == S
+		if (border == W && sam->direction == S
 		|| border == N && sam->direction == E)
 		sam->pixmap = AngleNw;
-	    if (border == E && sam->direction == S
+		if (border == E && sam->direction == S
 		|| border == N && sam->direction == W)
 		sam->pixmap = AngleNe;
-	    if(border == W && sam->direction == N
-	       || border == S && sam->direction == E)
+		if(border == W && sam->direction == N
+		   || border == S && sam->direction == E)
 		sam->pixmap = AngleSw;
-	    if(border == E && sam->direction == N
-	       || border == S && sam->direction == W)
+		if(border == E && sam->direction == N
+		   || border == S && sam->direction == W)
 		sam->pixmap = AngleSe;
 	}
 
 
-    } //end if (tail() > 1)
+	} //end if (tail() > 1)
 
-    if (tail() > 0) {
+	if (tail() > 0) {
 
 	sam = list.last();
 
 	switch (list.at(tail()-1)->direction) {
 	case N:
-	    sam->pixmap = TailUp;
-	    break;
+		sam->pixmap = TailUp;
+		break;
 	case S:
-	    sam->pixmap = TailDown;
-	    break;
+		sam->pixmap = TailDown;
+		break;
 	case E:
-	    sam->pixmap = TailRight;
-	    break;
+		sam->pixmap = TailRight;
+		break;
 	case W:
-	    sam->pixmap = TailLeft;
-	    break;
+		sam->pixmap = TailLeft;
+		break;
+	}
 	}
-    }
 }
 
 void Snake::repaint( bool dirty)
 {
-    int x = 0;
-    for ( Samy *sam = list.first(); sam != 0; sam = list.next(), x++) {
-	if (sam->index != OUT ) {
-	    if(!dirty && x > 1 && x < tail())
-		continue;
-	    pixServer->draw(sam->index, pixmap, sam->pixmap);
+	int x = 0;
+	for ( Samy *sam = list.first(); sam != 0; sam = list.next(), x++) {
+		if (sam->index != OUT ) {
+			if(!dirty && x > 1 && x < tail())
+				continue;
+			pixServer->draw(sam->index, pixmap, sam->pixmap);
 		}
-    }
-    if (!growing() && hold != OUT && hold != gate) {
-	pixServer->erase(hold);
-    }
+	}
+	if (!growing() && hold != OUT && hold != gate) {
+		pixServer->erase(hold);
+	}
 }
 
 
 CompuSnake::CompuSnake( Board *b, PixServer *p)
-    : Snake( b, p, NORTH_GATE, CompuSnakePix )
+	: Snake( b, p, NORTH_GATE, CompuSnakePix )
 {
-    init();
+	init();
 }
 
 bool CompuSnake::init()
 {
-    if( !list.isEmpty()) {
-	list.clear();
-    }
+	if( !list.isEmpty()) {
+		list.clear();
+	}
 
-    int index = NORTH_GATE;
-    int length = 12;
-    grow = 0;
-    hold = OUT;
+	int index = NORTH_GATE;
+	int length = 12;
+	grow = 0;
+	hold = OUT;
 
-    if ( !board->isBrick(gate) ) return FALSE;
+	if ( !board->isBrick(gate) ) return false;
 
-    Samy *sam;
-    for ( int x = 0; x < length; x++) {
-	board->set(index, snake);
-	sam = new Samy;
-	sam->direction = S;
-	sam->index = index;
-	sam->pixmap = (x == 0 ? HeadDown : BodyVt);
-	list.append(sam);
-	index = -1;
-    }
-    return TRUE;
+	Samy *sam;
+	for ( int x = 0; x < length; x++) {
+		board->set(index, snake);
+		sam = new Samy;
+		sam->direction = S;
+		sam->index = index;
+		sam->pixmap = (x == 0 ? HeadDown : BodyVt);
+		list.append(sam);
+		index = -1;
+	}
+	return true;
 }
 
 bool CompuSnake::permission()
 {
-    if( list.isEmpty() ){
+	if( list.isEmpty() ){
 
 	if ( hold != OUT) {
-	    emit killed();
-	    hold = OUT;
+		emit killed();
+		hold = OUT;
 	}
 
 	if(board->isBrick(gate)){
-	    static int  skip = 12;
-	    if (skip < 12) {
+		static int  skip = 12;
+		if (skip < 12) {
 		skip++;
-		return FALSE;
-	    } else {
+		return false;
+		} else {
 		skip = 0;
 		return init();
-	    }
+		}
 	}
-	else return FALSE;
-    }
-    else return TRUE;
+	else return false;
+	}
+	else return true;
 }
 
 void CompuSnake::nextMove()
 {
-    if (!permission()) return;
+	if (!permission())
+		return;
 
-    Samy *sam = list.first();
-    int  index = sam->index;
-    int  dir = sam->direction;
-    static bool varies = FALSE;
+	Samy *sam = list.first();
+	int  index = sam->index;
+	int  dir = sam->direction;
+	static bool varies = false;
 
 
-    bool found = FALSE;
+	bool found = false;
 
 	for ( int x = 0; x < 4 ; x++) {
-	    int next = board->getNext(x, sam->index);
-	    if (board->isApple(next)){
+		int next = board->getNext(x, sam->index);
+		if (board->isApple(next)){
 		index = next;
 		dir = x;
-		found = TRUE;
+		found = true;
 		grow+=6;
-		emit score(FALSE, index);
+		emit score(false, index);
 		break;
-	    }
+		}
 	}
 
-    if(!found)
+	if(!found)
 	for ( int x = 0; x < 4 ; x++) {
-	    int sq = emptySq[sam->direction][x];
-	    if (varies && (x > 0 && x < 3))
+		int sq = emptySq[sam->direction][x];
+		if (varies && (x > 0 && x < 3))
 		sq = opposite[sq];
-	    int next = board->getNext(sq, sam->index);
-	    if (findEmpty(next, x)) {
+		int next = board->getNext(sq, sam->index);
+		if (findEmpty(next, x)) {
 		index = next;
 		dir = sq;
-		found = TRUE;
+		found = true;
 		break;
-	    }
+		}
 	}
-    varies = !varies;
+	varies = !varies;
 
-    if(!found) {
+	if(!found) {
 	hold = list.last()->index;
 	if (board->isSnake(hold)) board->set(hold, empty);
 	removeSamy();
-    }
-    else
-	if(growing())
-	    appendSamy();
+	}
 	else
-	    if (!growing() && found) {
+	if(growing())
+		appendSamy();
+	else
+		if (!growing() && found) {
 		hold = list.last()->index;
 		if (board->isSnake(hold)) board->set(hold, empty);
 		updateSamy();
-	    }
+		}
 
-    if( !list.isEmpty()) {
+	if( !list.isEmpty()) {
 	board->set(index, snake);
 	reset(index, dir);
-    }
+	}
 
-    if ( hold == gate)
+	if ( hold == gate)
 	out();
 }
 
@@ -265,10 +286,10 @@ void KillerCompuSnake::nextMove()
 	Samy *sam = list.first();
 	int  index = sam->index;
 	int  dir = sam->direction;
-	static bool varies = FALSE;
+	static bool varies = false;
 	
 	
-	bool found = FALSE;
+	bool found = false;
 	
 	if(!found) {
 		int sn = board->samyHeadIndex();
@@ -277,7 +298,7 @@ void KillerCompuSnake::nextMove()
 			if(nextSq != -1) {
 				dir = board->direction(index, nextSq);
 				index = nextSq;
-				found = TRUE;
+				found = true;
 			}
 		}
 	}
@@ -291,7 +312,7 @@ void KillerCompuSnake::nextMove()
 			if (findEmpty(next, x)) {
 				index = next;
 				dir = sq;
-				found = TRUE;
+				found = true;
 				break;
 			}
 		}
@@ -331,19 +352,19 @@ void EaterCompuSnake::nextMove()
 	Samy *sam = list.first();
 	int  index = sam->index;
 	int  dir = sam->direction;
-	static bool varies = FALSE;
+	static bool varies = false;
 	
 	
-	bool found = FALSE;
+	bool found = false;
 	
 	for ( int x = 0; x < 4 ; x++) {
 		int next = board->getNext(x, sam->index);
 		if (board->isApple(next)){
 			index = next;
 			dir = x;
-			found = TRUE;
+			found = true;
 			grow+=6;
-			emit score(FALSE, index);
+			emit score(false, index);
 			break;
 		}
 	}
@@ -358,7 +379,7 @@ void EaterCompuSnake::nextMove()
 				if(nextSq != -1) {
 					dir = board->direction(index, nextSq);
 					index = nextSq;
-					found = TRUE;
+					found = true;
 					break;
 				}
 			}
@@ -369,7 +390,7 @@ void EaterCompuSnake::nextMove()
 			if(nextSq != -1) {
 				dir = board->direction(index, nextSq);
 				index = nextSq;
-				found = TRUE;
+				found = true;
 			}
 		}
 	}
@@ -383,7 +404,7 @@ void EaterCompuSnake::nextMove()
 			if (findEmpty(next, x)) {
 				index = next;
 				dir = sq;
-				found = TRUE;
+				found = true;
 				break;
 			}
 		}
@@ -418,119 +439,119 @@ void EaterCompuSnake::nextMove()
 
 bool CompuSnake::findEmpty(int i, int it)
 {
-    bool found = FALSE;
-    bool change = FALSE;
-    static int s_random =  random.getLong(BoardWidth/2);
-    static int moves  = 0;
+	bool found = false;
+	bool change = false;
+	static int s_random =  random.getLong(BoardWidth/2);
+	static int moves  = 0;
 
-    if (moves > s_random) {
-	s_random =  random.getLong(BoardWidth/2);
-	moves  = 0;
-	change = TRUE;
-    }
+	if (moves > s_random) {
+		s_random =  random.getLong(BoardWidth/2);
+		moves  = 0;
+		change = true;
+	}
 
-    found =  (   (  board->isEmpty(i) && it > 0)
+	found =  (   (  board->isEmpty(i) && it > 0)
 		 || (  board->isEmpty(i) && !change && it == 0) );
 
-    moves++;
-    change = FALSE;
-    return found;
+	moves++;
+	change = false;
+	return found;
 }
 
 void CompuSnake::removeSamy()
 {
-    list.remove();
-    grow = 0;
+	list.remove();
+	grow = 0;
 }
 
 void CompuSnake::out()
 {
-    emit closeGate( gate );
+	emit closeGate( gate );
 
-    if( list.isEmpty() )
-	return;
+	if( list.isEmpty() )
+		return;
 
-    if(list.first()->index == OUT) {
-	emit restartTimer();
-	list.clear();
-    }
+	if(list.first()->index == OUT) {
+		emit restartTimer();
+		list.clear();
+	}
 }
 
 SamySnake::SamySnake( Board *b, PixServer *p)
-    : Snake( b, p, SOUTH_GATE, SamyPix )
+	: Snake( b, p, SOUTH_GATE, SamyPix )
 {
 
 }
 
 void SamySnake::init()
 {
-    if( !list.isEmpty()) {
-	list.clear();
-    }
-    Samy *sam;
+	if( !list.isEmpty()) {
+		list.clear();
+	}
+	Samy *sam;
 
-    int index = SOUTH_GATE;
-    int length = 12;
-    grow = 0;
-    hold = 0;
-
-    for ( int x = 0; x < length; x++) {
-	board->set(index, head);
-	sam = new Samy;
-	sam->direction = N;
-	sam->index = index;
-	sam->pixmap = (x == 0 ? HeadUp : BodyVt);
-	list.append(sam);
-	index = -1;
-    }
+	int index = SOUTH_GATE;
+	int length = 12;
+	grow = 0;
+	hold = 0;
 
+	for ( int x = 0; x < length; x++) {
+		board->set(index, head);
+		sam = new Samy;
+		sam->direction = N;
+		sam->index = index;
+		sam->pixmap = (x == 0 ? HeadUp : BodyVt);
+		list.append(sam);
+		index = -1;
+	}
 }
 
 samyState SamySnake::nextMove(int direction)
 {
-    Samy *sam = list.first();
+	Samy *sam = list.first();
 
-    if(!board->isHead(sam->index) && sam->index != OUT)
-	return ko;
+	if(!board->isHead(sam->index) && sam->index != OUT)
+		return ko;
 
-    if ( direction == opposite[sam->direction])
-	direction = sam->direction;
+	if ( direction == opposite[sam->direction])
+		direction = sam->direction;
 
-    if(sam->index == gate || sam->index == OUT )
-	direction = N;
+	if(sam->index == gate || sam->index == OUT )
+		direction = N;
 
-    if (sam->index == NORTH_GATE) {
-	emit goingOut();
-	direction = N;
-    }
+	if (sam->index == NORTH_GATE) {
+		emit goingOut();
+		direction = N;
+	}
 
-    int index = board->getNext(direction, sam->index);
+	int index = board->getNext(direction, sam->index);
 
-    if (board->isApple(index)) {
+	if (board->isApple(index)) {
 		grow+=6;
-		emit score(TRUE, index);
-    }
-    else if (!board->isEmpty(index))
-	return ko;
+		emit score(true, index);
+	}
+	else if (!board->isEmpty(index))
+		return ko;
 
-    if(growing())
-	appendSamy();
-    else {
-	hold = list.last()->index;
-	board->set(hold, empty);
-	updateSamy();
-    }
+	if(growing())
+		appendSamy();
+	else {
+		hold = list.last()->index;
+		board->set(hold, empty);
+		updateSamy();
+	}
 
-    board->set(sam->index, snake);
-    reset(index, direction);
-    board->set(index, head);
+	board->set(sam->index, snake);
+	reset(index, direction);
+	board->set(index, head);
 
-    if ( hold == gate)
-	emit closeGate( gate );
-    else if ( hold == NORTH_GATE)
-	return out;
+	if ( hold == gate)
+		emit closeGate( gate );
+	else if ( hold == NORTH_GATE)
+		return out;
 
-    return ok;
+	return ok;
 }
 
 #include "snake.moc"
+
