@@ -15,7 +15,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   *****************************************************************************/
 
@@ -23,7 +23,6 @@
 
 #include <kconfigdialog.h>
 #include <klocale.h>
-#include <kkeydialog.h>
 #include <kmessagebox.h>
 #include <kaction.h>
 #include <kstdgameaction.h>
@@ -55,35 +54,39 @@ KTron::KTron(QWidget *parent, const char *name) : KMainWindow(parent, name) {
   statusBar()->insertItem("abcdefghijklmnopqrst: 0  ",ID_STATUS_BASE+1);
   statusBar()->insertItem("abcdefghijklmnopqrst: 0  ",ID_STATUS_BASE+2);
 
-  actionCollection()->setAutoConnectShortcuts(false);
-  (void)new KAction(i18n("Player 1 Up"), Key_R, 0, 0, actionCollection(), "Pl1Up");
-  (void)new KAction(i18n("Player 1 Down"), Key_F, 0, 0, actionCollection(), "Pl1Down");
-  (void)new KAction(i18n("Player 1 Right"), Key_G, 0, 0, actionCollection(), "Pl1Right");
-  (void)new KAction(i18n("Player 1 Left"), Key_D, 0, 0, actionCollection(), "Pl1Left");
-  (void)new KAction(i18n("Player 1 Accelerator"), Key_A, 0, 0, actionCollection(), "Pl1Ac");
+  // We match up keyboard events ourselves in Tron::keyPressEvent()
+  // We must disable the actions, otherwise we don't get the keyPressEvent's
+  KAction *act;
+  act = new KAction(i18n("Player 1 Up"), Key_R, 0, 0, actionCollection(), "Pl1Up");
+  act->setEnabled(false);
+  act = new KAction(i18n("Player 1 Down"), Key_F, 0, 0, actionCollection(), "Pl1Down");
+  act->setEnabled(false);
+  act = new KAction(i18n("Player 1 Right"), Key_G, 0, 0, actionCollection(), "Pl1Right");
+  act->setEnabled(false);
+  act = new KAction(i18n("Player 1 Left"), Key_D, 0, 0, actionCollection(), "Pl1Left");
+  act->setEnabled(false);
+  act = new KAction(i18n("Player 1 Accelerator"), Key_A, 0, 0, actionCollection(), "Pl1Ac");
+  act->setEnabled(false);
  
-  (void)new KAction(i18n("Player 2 Up"), Key_Up, 0, 0, actionCollection(), "Pl2Up");
-  (void)new KAction(i18n("Player 2 Down"), Key_Down, 0, 0, actionCollection(), "Pl2Down");
-  (void)new KAction(i18n("Player 2 Right"), Key_Right, 0, 0, actionCollection(), "Pl2Right");
-  (void)new KAction(i18n("Player 2 Left"), Key_Left, 0, 0, actionCollection(), "Pl2Left");
-  (void)new KAction(i18n("Player 2 Accelerator"), Key_0, 0, 0, actionCollection(), "Pl2Ac");
-
-  actionCollection()->setAutoConnectShortcuts(true);
+  act = new KAction(i18n("Player 2 Up"), Key_Up, 0, 0, actionCollection(), "Pl2Up");
+  act->setEnabled(false);
+  act = new KAction(i18n("Player 2 Down"), Key_Down, 0, 0, actionCollection(), "Pl2Down");
+  act->setEnabled(false);
+  act = new KAction(i18n("Player 2 Right"), Key_Right, 0, 0, actionCollection(), "Pl2Right");
+  act->setEnabled(false);
+  act = new KAction(i18n("Player 2 Left"), Key_Left, 0, 0, actionCollection(), "Pl2Left");
+  act->setEnabled(false);
+  act = new KAction(i18n("Player 2 Accelerator"), Key_0, 0, 0, actionCollection(), "Pl2Ac");
+  act->setEnabled(false);
 
   tron->setActionCollection(actionCollection());
 
   KStdGameAction::pause(tron, SLOT(togglePause()), actionCollection());
   KStdGameAction::gameNew( tron, SLOT( newGame() ), actionCollection() );
   KStdGameAction::quit(this, SLOT( close() ), actionCollection());
-
-  KStdAction::keyBindings(this, SLOT(configureKeys()), actionCollection());
-   
   KStdAction::preferences(this, SLOT(showSettings()), actionCollection());
-  createStandardStatusBarAction();
 
-  createGUI();
-  resize(400,300);
-  setAutoSaveSettings();
+  setupGUI( KMainWindow::Keys | StatusBar | Save | Create);
   loadSettings();
 }
 
@@ -172,13 +175,6 @@ void KTron::paletteChange(const QPalette &/*oldPalette*/){
    tron->update();
 }
 
-/**
- * Bring up the key configuration dialog.
- */ 
-void KTron::configureKeys(){
-  KKeyDialog::configure(actionCollection(), this);
-}
-
 /**
  * Show Settings dialog.
  */
@@ -188,7 +184,7 @@ void KTron::showSettings(){
   
   KConfigDialog *dialog = new KConfigDialog(this, "settings", Settings::self());
   dialog->addPage(new General(0, "General"), i18n("General"), "package_settings");
-  dialog->addPage(new Ai(0, "Ai"), i18n("Ai"), "package_system");
+  dialog->addPage(new Ai(0, "Ai"), i18n("A.I."), "personal");
   dialog->addPage(new Appearance(0, "Appearance"), i18n("Appearance"), "style");
   connect(dialog, SIGNAL(settingsChanged()), tron, SLOT(loadSettings()));
   connect(dialog, SIGNAL(settingsChanged()), this, SLOT(loadSettings()));
