@@ -13,11 +13,11 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 /*
-    $Id: kcarddialog.cpp 247271 2003-08-31 17:50:49Z mlaurent $
+    $Id: kcarddialog.cpp 465369 2005-09-29 14:33:08Z mueller $
 */
 
 #include <stdio.h>
