@@ -14,11 +14,11 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 /*
-    $Id: kgame.h 377450 2005-01-11 12:51:23Z mlaurent $
+    $Id: kgame.h 465369 2005-09-29 14:33:08Z mueller $
 */
 #ifndef __KGAME_H_
 #define __KGAME_H_
